@@ -17,10 +17,16 @@ import requests0 as requests
 from datetime import datetime
 import base64
 
-_4CHAN_API = 'api.4chan.org'
 _4CHAN_BOARDS_URL = 'boards.4chan.org'
-_4CHAN_IMAGES_URL = 'images.4chan.org'
-_4CHAN_THUMBS_URL = '0.thumbs.4chan.org'
+_4CHAN_API = 'a.4cdn.org'
+_4CHAN_IMAGES_URL = 'i.4cdn.org'
+_4CHAN_THUMBS_URL = 't.4cdn.org'
+
+#_4CHAN_BOARDS_URL = 'boards.4chan.org'
+#_4CHAN_API = 'api.4chan.org'
+#_4CHAN_IMAGES_URL = 'images.4chan.org'
+#_4CHAN_THUMBS_URL = '0.thumbs.4chan.org'
+
 _BOARD = '%s/%i.json'
 _THREAD = '%s/res/%i.json'
 _VERSION = '0.1.3'
